% PROPATHEO is a script for propagating theoretical pulses
% through real material.  It plots before and after amplitudes
% and phases in both domains.  Some typical values are
% entered, but pulsewidth or spectralwidth is definable, as
% well as temporal and/or spectral phase.

warning off;
MatrixSize = 256;
TimeWindow = 1500;
PhaseBlank = 0.005;
TimeStep = TimeWindow/MatrixSize;

% Pulse: All times in fs.  All Wavelengths in nm.
L0 = 800;
% pulsewidth = 94; % Leave spectralwidth as [] to use this.
% spectralwidth = [];
spectralwidth = 13; % Leave as [] to use the 'pulsewidth'
if not(isempty(spectralwidth))
    pulsewidth = ((L0/800)^2)*940/spectralwidth;
end
    
% Time Domain Phase
LinPhase = 0;
QuadPhase = 0;
CubicPhase = 0;
TempPhase = [0,LinPhase,QuadPhase,CubicPhase];
% Spectral Domain Phase
LinPhaseS = 0;
QuadPhaseS = -450;
CubicPhaseS = 0;
SpecPhase = [0,LinPhaseS,QuadPhaseS,CubicPhaseS];

[ET,T,ES,W] = pulsegenerator(MatrixSize,@fgaussian,pulsewidth,...
    TimeStep,L0,TempPhase,[],SpecPhase);
Wavelen = ltow(W);

% % To simulate a typical GRENOUILLE, use:
direction = 1;
ESNew = quickscale(BetaGREN(Wavelen,ES,direction));
%
% Change the 'direction' to 1 for forward propagation.
% Change the 'direction' to -1 for backward propagation.

% % To simulate just one chunk of material, use:
% len = 2.4;
% mat = 'FUSED SILICA';
% ESNew = quickscale(propagate(Wavelen,ES,len,mat));

ETNew = quickscale(ifftc(ESNew));

TemporalFWHMbefore = sprintf('FWHM = %6.1f fs',fwhm(IandP(ET),T));
TemporalFWHMafter = sprintf('FWHM = %6.1f fs',fwhm(IandP(ETNew),T));
SpectralFWHMbefore = sprintf('FWHM = %6.1f nm',fwhm(IandP(ES),ltow(W)));
SpectralFWHMafter = sprintf('FWHM = %6.1f nm',fwhm(IandP(ESNew),ltow(W)));


figure(42);clf;
% Before (back)propagation
subplot 231;
plotfrog(ET,ET,T,L0);
subplot 232;
plotcmplx(T,ET,[],[],PhaseBlank);
title(TemporalFWHMbefore);
subplot 233
plotcmplx(LtoW(W),ES,[],[],PhaseBlank);
title(SpectralFWHMbefore);

% After (back)propagation
subplot 234;
plotfrog(ETNew,ETNew,T,L0);
subplot 235;
plotcmplx(T,ETNew,[],[],PhaseBlank);
title(TemporalFWHMafter);
subplot 236
plotcmplx(LtoW(W),ESNew,[],[],PhaseBlank);
title(SpectralFWHMafter);

% Colormap HSV2 is for screens, HSV3 is for printing
colormap(hsv3);
warning on;
