function [L,E,W2] = ToConstWaveSpc(W,E,u)
%TOCONSTWAVESPC Converts E from constant frequency to constant wavelength spacing.
%	[L,E,W2]=TOCONSTWAVESPC(W,E,U) Converts E(W) to E(L) where E
%	is the electric field, W is the angular frequency array, L is the
%	wavelength array, W2 is the ang. frequencies corresponding the L,
%	and U is the units on the speed of light (defaults to 'nm/fs').

%	$Revision: 1.4 $ $Date: 2002/06/28 21:35:12 $
%
%	$Log: ToConstWaveSpc.m,v $
%	Revision 1.4  2002/06/28 21:35:12  zeekec
%	Revered column and rows for spline
%	
%	Revision 1.3  2002/05/09 18:40:45  pat
%	Changed to angular frequencies.
%	
%	Revision 1.2  2001/09/24 18:24:07  zeekec
%	Bug fix, isrow iscolumn
%	
%	Revision 1.1  2001/08/16 00:25:59  zeekec
%	Added function
%	

error(nargchk(2,3,nargin));

if (nargin < 3) | isempty(u)
	u = 'nm/fs';
end

ll = ltow(max(W));
lh = ltow(min(W));
l0 = mean([ll lh]);
%l0=1;

L = linspace(ll,lh,length(W));

L = reshape(L, size(W));

W2 = ltow(L);
C = L.^2 / l0^2;

if iscolumn(W)
	E = spline(W',E',W2')' .* repmat(C,1,size(E,2));
else
	E = spline(W, E, W2)   .* repmat(C,size(E,1),1);
end

