function x = const_c(s)
%CONST_C  The speed if light.
%	CONST_C returns the speed of light in nm/fs.
%	CONST_C(S) returns the speed of light in the specified SI units.

%	$Revision: 1.3 $  $Date: 2001/09/05 00:13:46 $
%
%	v1.0, 6/22/01, Erik Zeek, <zeekec@mad.scientist.com>
%	v1.1, 6/26/01, Erik Zeek, <zeekec@mad.scientist.com>
%
%	$Log: const_c.m,v $
%	Revision 1.3  2001/09/05 00:13:46  zeekec
%	Only accepts 1 '/' now.
%	
%	Revision 1.2  2001/07/06 15:27:32  zeekec
%	Removed ga_mathworks
%	

error(nargchk(0,1,nargin))

if nargin < 1
	s = 'nm/fs';
end

x = 299792458;

i = find(s=='/');

if length(i)~=1
	error(['Units should be of the form, xm/ys, not ' s '.']);
end

s1 = s(1:i-1);
s2 = s(i+1:length(s));
if s1(length(s1)) ~= 'm'
	error(['The base units of length should be m, not ' s1(length(s1)) ...
			', in ' s '.'])
end

if s2(length(s2)) ~= 's'
	error(['The base units of time should be s, not ' s2(length(s2)) ...
			', in ' s '.'])
end

if length(s1) > 1
	x = x / unitscale(s1(1:(length(s1)-1)));
end

if length(s2) > 1
	x = x * unitscale(s2(1:(length(s2)-1)));
end

