function E = propagate(wavelength,E,L,varargin)

% PROPAGATE (Back)Propagates pulse through material
%     PROPAGATE(WAVELENGTH,E,LENGTH,MATERIAL,DIRECTION,POLARIZATION,UNITS)
%     returns the complex electric field of an input field E with a given
%     POLARIZATION going through a MATERIAL of length L (given in UNITS), as
%     a function of WAVELENGTH (in nm). DIRECTION = +1 is forward
%     propagation, and DIRECTION = -1 is backwards propagation.
% 
% Note that WAVELENGTH must be in nm.
% The default values are:
% MATERIAL = 'BK7'
% DIRECTION = 1
% POLARIZATION = 'O'
% UNITS = 'mm'

%	$Revision: 1.7 $ $Date: 2002/06/19 19:20:04 $
%
%	$Log: propagate.m,v $
%	Revision 1.7  2002/06/19 19:20:04  pat
%	*** empty log message ***
%	
%	Revision 1.6  2002/04/30 16:18:11  pat
%	Fixed direction of propogation.
%	
%	Revision 1.5  2002/02/21 18:10:08  pat
%	Fixed centering bug
%	
%	Revision 1.4  2002/01/31 21:01:50  pat
%	Fixed OR bug in IF statement.
%	
%	Revision 1.3  2002/01/31 15:52:13  pat
%	*** empty log message ***
%	
%	Revision 1.2  2001/12/20 20:56:40  pat
%	*** empty log message ***
%	
%	Revision 1.1  2001/12/19 21:04:23  pat
%	Created
%	
%
%   v1.0, 12/19/01, Patrick O'Shea <pat@socrates.gatech.edu>
%

error(nargchk(3,7,nargin))

[material,direction,polarization,u] = parsevarargin(varargin,'BK7',1,'O','mm');

[x,b] = units(u);

if b~='m'
    error(['The base unit should be m, not ' b '.'])
end

if and(direction ~= 1, direction ~= -1)
    error(sprintf('The direction should be 1 or -1, not %g',direction))
end
    
L = L * x / units('nm');

n = refindex(wavelength,material,polarization,'nm');

knl = L*n.*2.*pi./wavelength;

if isrow(E)
    E = E.*exp(-1*direction*i.*knl);
else
    E = E.';knl = knl.';
    E = E.*exp(-1.*direction.*i.*knl);
    E = E.';knl = knl.';
end

E = fftc(center(ifftc(E),'max'));
